// http://www.mkyong.com/java/how-to-read-input-from-console-java

import java.util.Scanner;

public class ReadConsoleScanner {
  public static void main(String[] args) {
    
	  System.out.println("Enter something here : ");
    
	   String sWhatever;
     
       Scanner scanIn = new Scanner(System.in);
       sWhatever = scanIn.nextLine();

       scanIn.close();            
       System.out.println(sWhatever);
  }
}

/*
 * BufferedReader or Scanner:
 * Which one is better? Should we go for BufferedReader or Scanner?
 * Scanner is a new class since JDK1.5, it’s come out more easy way to read
 * input from file, and code is more clean.
*/

